****************************************************************
****Replication file for Tables and Figures of the manuscript*** 
****************************************************************

***Load data
clear all
set more off

global outpath 	"X:\analyses\"
use  "${outpath}scaling_back.dta", clear

xtset id wave

***************
***Variables***
***************
/*
x = mean centered WFC
y1 = job pressure
y2 = work hours
sex = gender
z1 = individual-level gender ideology
z2 = couple's gender ideology (dis)agreement
a = number of children
a2 = change in number of children
b = age of youngest child in the household categorial
c =marital status
d = partner's work hours
e = division of chores
f = divison of childcare
g = educational difference between the partners
h = ISEI
i = fixed-term employment contract
j = working in public sector
k = same occupation as in previous wave
l = same occupational status as in previous wave
cohort = cohort = age cohort
east = living in East Germany
nonmiss = estimation sample
weight_post = weight with post-stratification
*/

***********************************************************************************
***Table 1. Descriptive statistics for mothers (N = 791) and fathers (N = 1292).***
***********************************************************************************

foreach n of numlist 0 1 {
sum l.y1 y1 d.y1 l.y2 y2 d.y2 l.x if nonmiss==1 & sex==`n'
}
foreach x in l.y1 y1 l.y2 y2 l.x {
reg `x' i.sex if nonmiss==1, nohead
}
*family variables
foreach n of numlist 0 1 {
sum l.a a l.d d l.f f l.e e l2.z1 l2.pz1 if nonmiss==1 & sex==`n'
}
foreach x in l.a a l.d d l.f f l.e e l2.z1 l2.pz1 {
reg `x' i.sex if nonmiss==1, nohead
}
foreach n of numlist 0 1 {
sum l.b_* l.g_* l.c if nonmiss==1 & sex==`n'
}
foreach x in l.b_1 l.b_2 l.b_3 l.b_4 l.g_1 l.g_2 l.g_3 l.c {
logit `x' i.sex if nonmiss==1, nohead
}
*work variables
foreach n of numlist 0 1 {
sum l.h l.i l.j k k if nonmiss==1 & sex==`n'
}
reg l.h i.sex if nonmiss==1, nohead
foreach x in l.i l.j k k {
logit `x' i.sex if nonmiss==1, nohead
}
*demographic variables
foreach n of numlist 0 1 {
sum cohort* east if nonmiss==1 & sex==`n'
}
foreach x in cohort1 cohort2 cohort3 east {
logit `x' i.sex if nonmiss==1, nohead
}

***************************************************************************************
***Table 2. Ordinary Least Squares Regression of Changes in Job Pressure (N = 2083).***
***************************************************************************************

local conflict1 c.x
local family l.a a2 ib4.l.b l.d d.d ib2.l.g l.f d.f l.e d.e l.c
local work l.h l.y2 l.i l.j i.k i.k 
local socio_demo ib3.cohort i.east

qui reg d.y1 `conflict1' i.sex i.l2.z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
estimates store P1
qui reg d.y1 `conflict1'##i.sex i.l2.z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
estimates store P2
qui reg d.y1 `conflict1'##i.sex##i.l2.z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
estimates store P3
qui reg d.y1 i.sex##`conflict1'##c.z2  `values'  `family'   `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
estimates store P4

estout P1 P2 P3 P4, cells(b(star fmt(3))) starlevel(+ 0.1 * 0.05 ** 0.01 *** 0.001) stats(r2 r2_a N)

*Chow-Tests
local conflict1 c.x
local family l.a a2 ib4.l.b l.d d.d ib2.l.g l.f d.f l.e d.e l.c
local work l.h l.y2 l.i l.j i.k i.k 
local socio_demo ib3.cohort i.east
qui reg d.y1 `conflict1'##i.sex##i.l2.z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
testparm 1.sex#c.x#i.l2.z1
test 1.sex#c.x#0.l2.z1 = 0.sex#c.x#0.l2.z1 //strongly egalitarian
test 1.sex#c.x#1.l2.z1 = 0.sex#c.x#1.l2.z1 //egalitarian
test 1.sex#c.x#2.l2.z1 = 0.sex#c.x#2.l2.z1 //in between
test 1.sex#c.x#3.l2.z1 = 0.sex#c.x#3.l2.z1 //(strongly) traditional

qui reg d.y1 i.sex##`conflict1'##c.z2  `values'  `family'   `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
testparm 1.sex#c.x#c.z2

*************************************************************************************
***Table 3. Ordinary Least Squares Regression of Changes in Work Hours (N = 2083).***
*************************************************************************************

local conflict1 c.x
local family l.a a2 ib4.l.b l.d d.d ib2.l.g l.f d.f l.e d.e l.c
local work l.h l.i l.j l.y1 i.k i.k 
local socio_demo ib3.cohort i.east

qui reg d.y2 `conflict1' i.sex i.l2.z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
estimates store J1
qui reg d.y2 `conflict1'##i.sex i.l2.z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
estimates store J2
qui reg d.y2 `conflict1'##i.sex##i.l2.z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
estimates store J3
qui reg d.y2 i.sex##`conflict1'##c.z2  `values'  `family'   `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
estimates store J4

estout J1 J2 J3 J4, cells(b(star fmt(3))) starlevel(+ 0.1 * 0.05 ** 0.01 *** 0.001) stats(r2 r2_a N)

*Chow-Tests
local conflict1 c.x
local family l.a a2 ib4.l.b l.d d.d ib2.l.g l.f d.f l.e d.e l.c
local work l.h l.i l.j l.y1 i.k i.k 
local socio_demo ib3.cohort i.east

qui reg d.y2 `conflict1'##i.sex##i.l2.z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
testparm 1.sex#c.x#i.l2.z1
test 1.sex#c.x#0.l2.z1 = 0.sex#c.x#0.l2.z1 //strongly egalitarian
test 1.sex#c.x#1.l2.z1 = 0.sex#c.x#1.l2.z1 //egalitarian
test 1.sex#c.x#2.l2.z1 = 0.sex#c.x#2.l2.z1 //in between
test 1.sex#c.x#3.l2.z1 = 0.sex#c.x#3.l2.z1 //(strongly) traditional

qui reg d.y2 i.sex##`conflict1'##c.z2  `values'  `family'   `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
testparm 1.sex#c.x#c.z2

********************************************************************************************************************************************************
***Figure 1. Predicted change in job pressure by the level of work-family conflict (1=low, 5=high) for different gender ideologies divided by gender.***
********************************************************************************************************************************************************

local conflict1 c.x
local family l.a a2 ib4.l.b l.d d.d ib2.l.g l.f d.f l.e d.e l.c
local work l.h l.y2 l.i l.j i.k i.k 
local socio_demo ib3.cohort i.east

qui reg d.y1 `conflict1'##i.sex##i.l2_z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
qui margins sex if l2_z1==0, at(c.x=(1 (1) 5)) vsquish
marginsplot, x(x) recast(line) ///
			 title("Gender Ideology: Strongly Egalitarian", size(medium)) xtitle("Work-Family Conflicts") ytitle("Changes in Job Pressure") ///
			 ylabel(-1 -.5 0 .5) ///
			 plot1opts(lcolor(black)) plot2opts(lcolor(gs6) lpattern("--")) ///
			 legend(order(3 "fathers" 4 "mothers") region(color(none))) ciopt(color(black%20)) ///
			 note("A)", pos(11) size(medium large) span) ///
			 plotregion(style(none)) saving(figure1_0, replace)
qui margins sex if l2_z1==1, at(c.x=(1 (1) 5)) vsquish
marginsplot, x(x) recast(line) ///
			 title("Gender Ideology: Egalitarian", size(medium)) xtitle("Work-Family Conflicts") ytitle("Changes in Job Pressure") ///
			 ylabel (-.5 0 .5) ///
			 plot1opts(lcolor(black)) plot2opts(lcolor(gs6) lpattern("--")) ///
			 legend(order(3 "fathers" 4 "mothers") region(color(none))) ciopt(color(black%20)) ///
			 note("B)", pos(11) size(medium large) span) ///
			 plotregion(style(none)) saving(figure1_1, replace)
qui margins sex if l2_z1==2, at(c.x=(1 (1) 5)) vsquish
marginsplot, x(x) recast(line) ///
			 title("Gender Ideology: In Between", size(medium)) xtitle("Work-Family Conflicts") ytitle("Changes in Job Pressure") ///
			 ylabel (-1 -.5 0 .5 1) ///
			 plot1opts(lcolor(black)) plot2opts(lcolor(gs6) lpattern("--")) ///
			 legend(order(3 "fathers" 4 "mothers") region(color(none))) ciopt(color(black%20)) ///
			 note("C)", pos(11) size(medium large) span) ///
			 plotregion(style(none)) saving(figure1_2, replace)
qui margins sex if l2_z1==3, at(c.x=(1 (1) 5)) vsquish
marginsplot, x(x) recast(line) ///
			 title("Gender Ideology: (Strongly) Traditional", size(medium)) xtitle("Work-Family Conflicts") ytitle("Changes in Job Pressure") ///
			 ylabel (-1 -.5 0 .5 1 1.5 2) ///
			 plot1opts(lcolor(black)) plot2opts(lcolor(gs6) lpattern("--")) ///
			 legend(order(3 "fathers" 4 "mothers") region(color(none))) ciopt(color(black%20)) ///
			 note("D)", pos(11) size(medium large) span) ///
			 plotregion(style(none)) saving(figure1_3, replace)

****************************************************************************************************************
***Figure 2. Predicted change in job pressure by the level of work-family conflict (1=low, 5=high) and gender***
***  ideology differences (-3=partner more traditional, 3=partner more egalitarian) for fathers and mothers. ***
****************************************************************************************************************

local conflict1 c.x
local family l.a a2 ib4.l.b l.d d.d ib2.l.g l.f d.f l.e d.e l.c
local work l.h l.y2 l.i l.j i.k i.k 
local socio_demo ib3.cohort i.east

qui reg d.y1 i.sex##`conflict1'##c.z2  `values'  `family'   `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
qui margins sex, at(x=(1 (1) 5) z2=(-3(1)3)) saving(pr_y1, replace)
use pr_y1, clear
rename (_m1 _at2 _at3 _margin) (sex x z2 pr_y1)

twoway contour pr_y1 z2 x if sex==0, ///
		ccuts(-.358756(.18195812).5510346) ///
		ccolor(gs0 gs3 gs6 gs9 gs12 gs15) ///
		ztitle("Changes in Job Pressure") ///
		yscale(range(-3 3)) ylab(-3(1)3) ///
		xtitle("Work-Family Conflicts") ///
		ytitle("Gender Ideology Differences")  ///
		title("Fathers", size(medium)) ///
		note("A)", pos(11) size(medium large) span) saving(figure3_1, replace)

twoway contour pr_y1 z2 x if sex==1, ///
		ccuts(-.358756(.18195812).5510346) ///
		ccolor(gs0 gs3 gs6 gs9 gs12 gs15) ///
		ztitle("Changes in Job Pressure") ///
		yscale(range(-3 3)) ylab(-3(1)3) ///
		xtitle("Work-Family Conflicts") ///
		ytitle("Gender Ideology Differences")  ///
		title("Mothers", size(medium)) ///
		note("B)", pos(11) size(medium large) span) saving(figure3_2, replace)

******************************************************************************************************************************************************
***Figure 3. Predicted change in work hours by the level of work-family conflict (1=low, 5=high) for different gender ideologies divided by gender.***
******************************************************************************************************************************************************

local conflict1 c.x
local family l.a a2 ib4.l.b l.d d.d ib2.l.g l.f d.f l.e d.e l.c
local work l.h l.y1 l.i l.j i.k i.k 
local socio_demo ib3.cohort i.east

qui reg d.y2 `conflict1'##i.sex##l2_z1 `family' `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
qui margins sex if l2_z1==0, at(c.x=(1 (1) 5)) vsquish
marginsplot, x(x) recast(line) ///
			 title("Gender Ideology: Strongly Egalitarian", size(medium)) xtitle("Work-Family Conflicts") ytitle("Changes in Work Hours") ///
			 ylabel (-6 (2) 4) ///
			 plot1opts(lcolor(black)) plot2opts(lcolor(gs6) lpattern("--")) ///
			 legend(order(3 "fathers" 4 "mothers") region(color(none))) ciopt(color(black%20)) ///
			 note("A)", pos(11) size(medium large) span) ///
			 plotregion(style(none)) saving(figure2_0, replace)
qui margins sex if l2_z1==1, at(c.x=(1 (1) 5)) vsquish
marginsplot, x(x) recast(line) ///
			 title("Gender Ideology: Egalitarian", size(medium)) xtitle("Work-Family Conflicts") ytitle("Changes in Work Hours") ///
			 ylabel (-4 (2) 4) ///
			 plot1opts(lcolor(black)) plot2opts(lcolor(gs6) lpattern("--")) ///
			 legend(order(3 "fathers" 4 "mothers") region(color(none))) ciopt(color(black%20)) ///
			 note("B)", pos(11) size(medium large) span) ///
			 plotregion(style(none)) saving(figure2_1, replace)
qui margins sex if l2_z1==2, at(c.x=(1 (1) 5)) vsquish
marginsplot, x(x) recast(line) ///
			 title("Gender Ideology: In Between", size(medium)) xtitle("Work-Family Conflicts") ytitle("Changes in Work Hours") ///
			 ylabel (-4 (2) 4) ///
			 plot1opts(lcolor(black)) plot2opts(lcolor(gs6) lpattern("--")) ///
			 legend(order(3 "fathers" 4 "mothers") region(color(none))) ciopt(color(black%20)) ///
			 note("C)", pos(11) size(medium large) span) ///
			 plotregion(style(none)) saving(figure2_2, replace)
qui margins sex if l2_z1==3, at(c.x=(1 (1) 5)) vsquish
marginsplot, x(x) recast(line) ///
			 title("Gender Ideology: (Strongly) Traditional", size(medium)) xtitle("Work-Family Conflicts") ytitle("Changes in Work Hours") ///
			 ylabel (-4 (2) 10) ///
			 plot1opts(lcolor(black)) plot2opts(lcolor(gs6) lpattern("--")) ///
			 legend(order(3 "fathers" 4 "mothers") region(color(none))) ciopt(color(black%20)) ///
			 note("D)", pos(11) size(medium large) span) ///
			 plotregion(style(none)) saving(figure2_3, replace)

***************************************************************************************************************
***Figure 4. Predicted change in work hours by the level of work-family conflicts (1=low, 5=high) and gender***
*** ideology differences (-3=partner more traditional, 3=partner more egalitarian) for fathers and mothers. ***
***************************************************************************************************************

local conflict1 c.x
local family l.a a2 ib4.l.b l.d d.d ib2.l.g l.f d.f l.e d.e l.c
local work l.h l.y1 l.i l.j i.k i.k 
local socio_demo ib3.cohort i.east

qui reg d.y2 i.sex##`conflict1'##c.z2  `values'  `family'   `work' `socio_demo' if est_sample~=. & nonmiss==1 [pweight=weight_post] , vce(cluster id)
qui margins sex, at(x=(1 (1) 5) z2=(-3(1)3)) saving(pr_y2, replace)
use pr_y2, clear
rename (_m1 _at2 _at3 _margin) (sex x z2 pr_y2)

twoway contour pr_y2 z2 x if sex==0, ///
		ccuts(-3.447256(1.0696522)1.901005) ///
		ccolor(gs0 gs3 gs6 gs9 gs12 gs15) ///
		ztitle("Changes in Work Hours") ///
		yscale(range(-3 3)) ylab(-3(1)3) ///
		xtitle("Work-Family Conflicts") ///
		ytitle("Gender Ideology Differences")  ///
		title("Fathers", size(medium)) ///
		note("A)", pos(11) size(medium large) span) saving(figure4_1, replace)

twoway contour pr_y2 z2 x if sex==1, ///
		ccuts(-3.447256(1.0696522)1.901005) ///
		ccolor(gs0 gs3 gs6 gs9 gs12 gs15) ///
		ztitle("Changes in Work Hours") ///
		yscale(range(-3 3)) ylab(-3(1)3) ///
		xtitle("Work-Family Conflicts") ///
		ytitle("Gender Ideology Differences")  ///
		title("Mothers", size(medium)) ///
		note("B)", pos(11) size(medium large) span) saving(figure4_2, replace)
